#ifndef _OC2335_INCLUDE_
#define _OC2335_INCLUDE_

#ifdef _OC2335_DRIVER_

/* version-dependent functions/structures */

#if LINUX_VERSION_CODE >= 0x020318
#define OC2335_NETDEV net_device
#else
#define OC2335_NETDEV device
#endif

/* When did that change exactly ? */

#if (LINUX_VERSION_CODE >= 0x20200)
#define OC2335_KFREE(skb) dev_kfree_skb(skb)
#else
#define OC2335_KFREE(skb) dev_kfree_skb(skb, FREE_WRITE);
#endif

#if (LINUX_VERSION_CODE >= 0x020363)
#define OC2335_STAT net_device_stats
#else
#define OC2335_STAT enet_statistics
#endif

/* maximum packet size - last value rounded up to DWords */

#define PKTSIZE 1518
#define RND_PKTSIZE 1520

/* Adapter ID's */

#define OC2335_ID 0x6447

/* # of TX buffers */

#define TXBUFCNT 4

typedef struct
        {
          unsigned int slot;       /* MCA-Slot-#                       */
          struct OC2335_STAT stat; /* packet statistics            */
          int realirq;             /* memorizes actual IRQ, even when 
                                      currently not allocated          */
          u16 txhandle;            /* handle no. of next frame         */
          u16 revision;            /* silicon revision                 */
          struct sk_buff *skbs[TXBUFCNT]; /* ahead buffer for Tx       */
          int skbcnt;              /* # of skb's in FIFO               */
        } oc2335_priv;

#define OC2335_IORANGE 0x20

/* National DP83800 register definitions: */ 

#define REG_CR        0x00         /* command register                 */
#define REG_CR_BISE   0x8000       /* built-in selftest error          */
#define REG_CR_SR     0x4000       /* software reset                   */
#define REG_CR_TXR    0x2000       /* transmit reset                   */
#define REG_CR_TXE    0x1000       /* transmit enable                  */
#define REG_CR_TRJ    0x0800       /* transmit packet reject           */
#define REG_CR_RXR    0x0400       /* receiver reset                   */
#define REG_CR_RXE    0x0200       /* receiver enable                  */
#define REG_CR_SWI    0x0100       /* software interrupt               */
#define REG_CR_MOD    0x0008       /* allow modifying bits 8..15       */
#define REG_CR_PG2    0x0004       /* page select bits                 */
#define REG_CR_PG1    0x0002
#define REG_CR_PG0    0x0001

#define REG_IVR       0x02         /* interrupt vector register        */
#define REG_IVR_RXB   0x04         /* receive complete with errors     */
#define REG_IVR_RXT   0x08         /* receive threshold                */
#define REG_IVR_RXC   0x0c         /* receive complete without errors  */
#define REG_IVR_TXB   0x10         /* transmit error                   */
#define REG_IVR_TXC   0x14         /* transmit complete                */
#define REG_IVR_TFS   0x18         /* transmit FIFO space available    */
#define REG_IVR_TMR   0x1c         /* timer interrupt                  */
#define REG_IVR_SWI   0x20         /* software interrupt               */
#define REG_IVR_MIB   0x24         /* MIB counter overflow             */
#define REG_IVR_TFE   0x28         /* transmit FIFO error              */
#define REG_IVR_RFE   0x2c         /* receive FIFO error               */

#define REG_TSR       0x06         /* transmit status register         */
#define REG_TSR_TACT  0x8000       /* transmitter active               */
#define REG_TSR_TS    0x4000       /* transmission successful          */
#define REG_TSR_TD    0x2000       /* transmission deferred            */
#define REG_TSR_THV   0x1000       /* transmit handle valid            */
#define REG_TSR_TXA   0x0400       /* transmit abort                   */
#define REG_TSR_CRS   0x0200       /* carrier sense lost               */
#define REG_TSR_TFU   0x0100       /* transmit FIFO underrun           */
#define REG_TSR_ED    0x0040       /* transmit excessive deferral      */
#define REG_TSR_OWC   0x0020       /* out of window collision          */
#define REG_TSR_EC    0x0010       /* excessive collisions             */
#define REG_TSR_CC    0x000f       /* collision count                  */

#define REG_RSR       0x08         /* receive status register          */
#define REG_RSR_PRC   0x8000       /* packet reception complete        */
#define REG_RSR_PROK  0x4000       /* packet received OK               */
#define REG_RSR_BC    0x0fff       /* remaining byte count for packet  */

#define REG_RPAR      0x0a         /* recv packet adv/mgmt register    */
#define REG_RPAR_CRJ  0x0400       /* CAM reject                       */
#define REG_RPAR_MCA  0x0200       /* multicast received               */
#define REG_RPAR_BCA  0x0100       /* broadcast received               */
#define REG_RPAR_PAM  0x0080       /* physical address match           */
#define REG_RPAR_LONG 0x0040       /* jabber packet received           */
#define REG_RPAR_RUNT 0x0020       /* runt packet received             */
#define REG_RPAR_COL  0x0010       /* collision activity               */
#define REG_RPAR_ISE  0x0008       /* invalid symbol error             */
#define REG_RPAR_LBP  0x0004       /* loopback packet received         */
#define REG_RPAR_CRCE 0x0002       /* CRC error                        */
#define REG_RPAR_FAE  0x0001       /* frame alignment error            */

#define REG_TRDR0     0x0c         /* transmit/receive data register   */
#define REG_TRDR1     0x0e

#define REG_IMR       0x14         /* interrupt mask register (page 0) */
#define REG_IMR_TFE   0x0400       /* transmit FIFO error              */
#define REG_IMR_RFE   0x0200       /* receive FIFO error               */
#define REG_IMR_MIB   0x0100       /* MIB counter overflow             */
#define REG_IMR_SWI   0x0080       /* software interrupt               */
#define REG_IMR_TMR   0x0040       /* timer error                      */
#define REG_IMR_TXB   0x0020       /* transmit error                   */
#define REG_IMR_TFS   0x0010       /* transmit FIFO space available    */
#define REG_IMR_TXC   0x0008       /* transmit complete                */
#define REG_IMR_RXT   0x0004       /* receive threshold                */
#define REG_IMR_RXB   0x0002       /* receive error                    */
#define REG_IMR_RXC   0x0001       /* receive complete                 */

#define REG_TXCR      0x16         /* transmit ctrl register (page 0)  */
#define REG_TXCR_CSI  0x0200       /* carrier sense ignore             */
#define REG_TXCR_HBI  0x0100       /* heart beat ignore                */
#define REG_TXCR_MLB  0x0080       /* MAC loopback                     */
#define REG_TXCR_ATP  0x0040       /* automatic tranmit padding        */
#define REG_TXCR_BLND 0x0000       /* blind transmit mode              */
#define REG_TXCR_HERR 0x0010       /* halt on error mode               */
#define REG_TXCR_ACK  0x0020       /* acknowledge mode                 */
#define REG_TXCR_IFG  0x0003       /* interframe gap mask              */

#define REG_RXCR      0x18         /* recv config register (page 0)    */
#define REG_RXCR_ATX  0x0008       /* allow receival while transmitting*/
#define REG_RXCR_AEP  0x0004       /* accept errored frames            */
#define REG_RXCR_ARP  0x0002       /* accept runt packets              */
#define REG_RXCR_AJAB 0x0001       /* accept jabber packets            */

#define REG_TMTR      0x12         /* tx min threshold reg (page 0)    */

#define REG_TFTR      0x14         /* tx free space thr reg (Page 1)   */

#define REG_TFSR      0x16         /* tx free space register (page 1)  */

#define REG_RTR       0x18         /* recv threshold register (page 1) */
#define REG_RTR_RTE   0x8000       /* enable receive threshold         */
#define REG_RTR_RTM   0x4000       /* threshold mode                   */
#define REG_RTR_RT11  0x0800       /* threshold value                  */
#define REG_RTR_RT10  0x0400
#define REG_RTR_RT9   0x0200
#define REG_RTR_RT8   0x0100
#define REG_RTR_RT7   0x0080
#define REG_RTR_RT6   0x0040
#define REG_RTR_RT5   0x0020
#define REG_RTR_RT4   0x0010
#define REG_RTR_RT3   0x0008
#define REG_RTR_RT2   0x0004
#define REG_RTR_RT1   0x0002
#define REG_RTR_RT0   0x0001

#define REG_IPR       0x1a         /* interrupt mask register (page 0) */
#define REG_IPR_TFE   0x0400       /* transmit FIFO error              */
#define REG_IPR_RFE   0x0200       /* receive FIFO error               */
#define REG_IPR_MIB   0x0100       /* MIB counter overflow             */
#define REG_IPR_SWI   0x0080       /* software interrupt               */
#define REG_IPR_TMR   0x0040       /* timer error                      */
#define REG_IPR_TXB   0x0020       /* transmit error                   */
#define REG_IPR_TFS   0x0010       /* transmit FIFO space available    */
#define REG_IPR_TXC   0x0008       /* transmit complete                */
#define REG_IPR_RXT   0x0004       /* receive threshold                */
#define REG_IPR_RXB   0x0002       /* receive error                    */
#define REG_IPR_RXC   0x0001       /* receive complete                 */

#define REG_IER       0x1e         /* interrupt enable register(page 1)*/
#define REG_IER_IE    0x0001       /* general interrupt enable         */

#define REG_EECR      0x10         /* EEPROM control register (page 2) */
#define REG_EECR_EIU  0x8000       /* EEPROM in use                    */
#define REG_EECR_EBE  0x4000       /* EEPROM BIST start                */
#define REG_EECR_EBF  0x2000       /* EEPROM BIST fail                 */
#define REG_EECR_RD   0x0080       /* EEPROM read (1-0)                */

#define REG_EEDR      0x12         /* EEPROM data register (page 2)    */

#define REG_CCR       0x18         /* CAM control register (page 2)    */
#define REG_CCR_CMEN  0x8000       /* enable CAM                       */
#define REG_CCR_AAB   0x4000       /* accept all broadcasts            */
#define REG_CCR_AAM   0x2000       /* accept all multicasts            */
#define REG_CCR_AAP   0x1000       /* accept all packets               */
#define REG_CCR_CMW   0x0080       /* initiate CAM write               */
#define REG_CCR_CMR   0x0040       /* initiate CAM read                */
#define REG_CCR_CE3   0x0008       /* CAM entry select bits            */
#define REG_CCR_CE2   0x0004
#define REG_CCR_CE1   0x0002
#define REG_CCR_CE0   0x0001

#define REG_CDR       0x1a         /* CAM data register (page 2)       */

#define REG_CMR       0x1c         /* CAM mask register (page 2)       */

#define REG_CMTR      0x1e         /* CAM match register (page 2)      */

#define REG_SSR       0x10         /* silicon rev register (page 4)    */

/* MAC Address offset in config EEPROM */

#define MACADDROFFS   0x24

#endif /* _OC2335_DRIVER_ */

extern int oc2335_probe(struct OC2335_NETDEV *);

#endif /* _OC2335_INCLUDE_ */
